/* Creates the bootstrapped samples for estimation */
/* For definitions of variables created here, */
/* see third_nber_wp_version.do */

/* Randomly draws daily observations BY HOUSEHOLD - i.e. draws clusters */

/* Currently set for two random draws - use 200 in the paper */

/* Creates 4 types of samples */
/* s1allX - random draws from all households keeping only */
/*          WEEK indicators (d_week1 d_week3 d_week4) */
/* s2allX - random draws from all households keeping only */
/*          DAY OF WINDOW indicators (d_min14 d_min13 d_min12 etc.) */
/* s170_X - same as s1allX but only HHs w/70% or more of income from SS */
/* s270_X - same as s2allX but only HHs w/70% or more of income from SS */

/* Datasets are comma separated ASCII files to convert into GAUSS datasets */

#delimit ';'
set memory 150000;
use ~/CEX/Diary/Perms/ssdaily.dta;
set matsize 200;


/* Set the global seed number */
global seedval "2112";


/* Household identifier */
gen hhid = cuid*100 + year;


/* USE ONLY 1986-1996 OBSERVATIONS */
drop if year<86;
drop if year>96;

/* Get count of total observations before cuts */
summarize newid; 

/* Keep those with complete income reports */
keep if respstat==1;


/* Cannot use January observations */
drop if jandif3a!=.;
/* Cannot use if falls outside 14 days before or 13 days after the third */
drop if anndif3a==.;


/* Use those with ANY income from SS and report it all */
gen ssratio = fss_rrx/fincbefx;
keep if fss_rrx>0&fss_rrx!=.;

gen ssrat70 = ssratio>=.70;


/* ONLY USE HOUSEHOLDS WHERE REFERENCE PERSON OR SPOUSE GETS S.S. */
keep if ss_rel1==1|ss_rel1==2|ss_rel2==2;

gen ref_ss = ss_rel1==1;
gen spous_ss = ss_rel1==2|ss_rel2==2;
gen both_ss = ref_ss==1&spous_ss==1;

/* Determine the number of obs per household */
gen diarydy2 = diaryday + 7*(weeki-1);
egen minday = min(diarydy2), by(hhid);
egen maxday = max(diarydy2), by(hhid);
gen firstday = minday==diarydy2;
gen numdays = maxday - minday + 1;
tabulate numdays if firstday==1;


/* CREATE SOME NEW VARIABLES */
/* stnondur is related to Lusardi's strict non-durable category */
/* But I've tried to eliminate things that might have a regular payment freq */
/* So, it is all food, all alcohol, all tobacco, all personal care, */
/* all public transportation, and all gas/motor oil . */
/* What I've left out from Lusardi is utilities, hhold operations, & miscel */
gen stnondur = foodtot2 + smoksupp + persprod + persserv + pubtran + gas;

/* stnondu2 is the same as xxxsndur except add in household products */
/* These include soap, cleaning products, paper towels, stationery, etc. */
gen stnondu2 = stnondur + housprod;

/* pure is a pure consumption category */
/* It is total away category (food & alcohol away plus MY entertainment cat) */
/* plus fresh foods */ 
gen pure = fresh + totaway;


/* Generate indicators for second survey week and days */
gen byte sweek2 = weeki==2;
gen byte swk2day2 = sweek2*survday2;
gen byte swk2day3 = sweek2*survday3;
gen byte swk2day4 = sweek2*survday4;
gen byte swk2day5 = sweek2*survday5;
gen byte swk2day6 = sweek2*survday6;
gen byte swk2day7 = sweek2*survday7;


/* Get bootstrapped samples here */

/* First save modified dataset */
/* KEEP ONLY needed variables to cut down on input/output time */ 
keep hhid totalexp apparel foodtot2 foodhom2 foodawa2 fresh
     totaway pure alchaway stnondur stnondu2
     survday2 survday3 survday4 survday5 survday6 survday7
     sweek2 swk2day2 swk2day3 swk2day4 swk2day5 swk2day6 swk2day7
     d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7
     d_min6 d_min5 d_min4 d_min3 d_min2 d_0 d_plus1 d_plus2 d_plus3
     d_plus4 d_plus5 d_plus6 d_plus7 d_plus8 d_plus9
     d_plus10 d_plus11 d_plus12 d_plus13
     d_week1 d_week3 d_week4
     tue wed thu fri sat sun
     ssrat70
     ;
save ~/CEX/Diary/Stata/Boot/Data/bootdat, replace;
summarize;
describe;
clear;


/* Then create bootstrapped samples for the entire sample */
/* USING WEEK INDICATORS BUT NOT DAILY INDICATORS */
/* MAKE SURE TO RESET SEED SO TAKING SAME SAMPLE */
set seed $seedval; /* Remember to reset the seed */
for num 1/2: use ~/CEX/Diary/Stata/Boot/Data/bootdat
   \ bsample, cluster(hhid) idcluster(bshhid)
   \ summarize
   \ outfile bshhid totalexp apparel foodtot2 foodhom2 foodawa2 fresh
             totaway pure alchaway stnondur stnondu2
             survday2 survday3 survday4 survday5 survday6 survday7
             sweek2 swk2day2 swk2day3 swk2day4 swk2day5 swk2day6 swk2day7
             d_week1 d_week3 d_week4
             tue wed thu fri sat sun
     using ~/CEX/Diary/Stata/Boot/Ascii/s1allX, comma replace wide
   \ clear;


/* Then create bootstrapped samples for the entire sample */
/* USING DAILY INDICATORS BUT NOT WEEKLY INDICATORS */
/* MAKE SURE TO RESET SEED SO TAKING SAME SAMPLE */
set seed $seedval; /* Remember to reset the seed */
for num 1/2: use ~/CEX/Diary/Stata/Boot/Data/bootdat
   \ bsample, cluster(hhid) idcluster(bshhid)
   \ summarize
   \ outfile bshhid totalexp apparel foodtot2 foodhom2 foodawa2 fresh
             totaway pure alchaway stnondur stnondu2
             survday2 survday3 survday4 survday5 survday6 survday7
             sweek2 swk2day2 swk2day3 swk2day4 swk2day5 swk2day6 swk2day7
             d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7
             d_min6 d_min5 d_min4 d_min3 d_min2 d_0 d_plus1 d_plus2 d_plus3
             d_plus4 d_plus5 d_plus6  d_plus7 d_plus8 d_plus9
             d_plus10 d_plus11 d_plus12 d_plus13
             tue wed thu fri sat sun
     using ~/CEX/Diary/Stata/Boot/Ascii/s2allX, comma replace wide
   \ clear;




/* Finally create bootstrapped samples for the THOSE WITH 70% OF INC FROM SS */
/* USING WEEK INDICATORS BUT NOT DAILY INDICATORS */
/* MAKE SURE TO RESET SEED SO TAKING SAME SAMPLE */
set seed $seedval; /* Remember to reset the seed */
for num 1/2: use ~/CEX/Diary/Stata/Boot/Data/bootdat
   \ keep if ssrat70==1
   \ bsample, cluster(hhid) idcluster(bshhid)
   \ summarize
   \ outfile bshhid totalexp apparel foodtot2 foodhom2 foodawa2 fresh
             totaway pure alchaway stnondur stnondu2
             survday2 survday3 survday4 survday5 survday6 survday7
             sweek2 swk2day2 swk2day3 swk2day4 swk2day5 swk2day6 swk2day7
             d_week1 d_week3 d_week4
             tue wed thu fri sat sun
     using ~/CEX/Diary/Stata/Boot/Ascii/s170_X, comma replace wide
   \ clear;


/* Finally create bootstrapped samples for the THOSE WITH 70% OF INC FROM SS */
/* USING DAILY INDICATORS BUT NOT WEEKLY INDICATORS */
/* MAKE SURE TO RESET SEED SO TAKING SAME SAMPLE */
set seed $seedval; /* Remember to reset the seed */
for num 1/2: use ~/CEX/Diary/Stata/Boot/Data/bootdat
   \ keep if ssrat70==1
   \ bsample, cluster(hhid) idcluster(bshhid)
   \ summarize
   \ outfile bshhid totalexp apparel foodtot2 foodhom2 foodawa2 fresh
             totaway pure alchaway stnondur stnondu2
             survday2 survday3 survday4 survday5 survday6 survday7
             sweek2 swk2day2 swk2day3 swk2day4 swk2day5 swk2day6 swk2day7
             d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7
             d_min6 d_min5 d_min4 d_min3 d_min2 d_0 d_plus1 d_plus2 d_plus3
             d_plus4 d_plus5 d_plus6  d_plus7 d_plus8 d_plus9
             d_plus10 d_plus11 d_plus12 d_plus13
             tue wed thu fri sat sun
     using ~/CEX/Diary/Stata/Boot/Ascii/s270_X, comma replace wide
   \ clear;
