/* Program to run NBER working paper version of third of tha month */
/* Variables that have been created from the original CEX data files */
/* are discussed below even if they are created in an earlier file */

/* DAILY EXPENDITURES */
/* USE EVERY CU RECEIVING SS */
/* HOUSEHOLDS IN WHICH REFERENCE PERSON OR SPOUSE RECEIVES SS */

#delimit ';'
set memory 150000;
use ~/PaperFinalProgs/Third/Perms/ssdaily8696.dta;
set matsize 200;

/* The dataset ssdaily.dta contains DAILY observations */
/* Have already converted to daily observations in previous programs */

/* Create a household identifier */
/* The variable CUID is the first 7 digits of the 8 digit identifier */
/* variable NEWID. The first 7 digits are unique to each household */
/* The eighth digit is either 1 or 2 for which diary week and is */
/* exactly the same as the variable WEEKI found on the FMLY files. */
/* To pool together the two weeks for a single household, CUID is used */
gen hhid = cuid*100 + year;


/* Get count of total observations before cuts */
summarize newid; 

/* Keep those with complete income reports */
keep if respstat==1;


/* Cannot use January observations */
/* JANDIF3A is ranges from -14 to 13 which is number of days before or */
/* after the check scheduled to come on January 3rd (or the check arrival */
/* date after adjustment for the 3rd falling on a holiday or weekend). */
/* This variable is created in each of the dailyYY.sas files which */
/* create the daily data for year YY */
drop if jandif3a!=.;

/* Cannot use if falls outside 14 days before or 13 days after the third */
/* ANNDIF3A is an annual measure created from JANDIF3A, FEBDIF3A, etc. */
/* If not within the 28 day window around ANY check date, then drop */
/* This variable is created in each of the dailyYY.sas files which */
/* create the daily data for year YY */
drop if anndif3a==.;


/* Use those with ANY income from SS and report it all */
gen ssratio = fss_rrx/fincbefx;
keep if fss_rrx>0&fss_rrx!=.;


/* ONLY USE HOUSEHOLDS WHERE REFERENCE PERSON OR SPOUSE GETS S.S. */
/* The variables SS_REL1, SS_REL2, and SS_REL3 contain the relation to */
/* the household head (CU_CODE1 on the member file) of the first three */
/* family members WHO RECEIVE SOCIAL SECURITY */
/* The "first three" are determined by an ascending sorted by cu_code1 */
/* Since CU_CODE1=1 for the head and =2 for the spouse of the head, */
/* if SS_REL1 is either 1 or 2, or SS_REL2 is 2, then either the head */
/* or the spouse of the head receives Social Security on the member file */
/* This variable is created in each of the dailyYY.sas files which */
/* create the daily data for year YY */
keep if ss_rel1==1|ss_rel1==2|ss_rel2==2;

gen ref_ss = ss_rel1==1;
gen spous_ss = ss_rel1==2|ss_rel2==2;
gen both_ss = ref_ss==1&spous_ss==1;


/* Determine the number of obs per household */
/* Households may have less than 14 days at this point since some */
/* days for a household may fall outside of a 28-day window centered */
/* around a check receipt date */

/* The variable DIARYDAY ranges from 1-7 and is the first character of */
/* the character variable QREDATE on the EXPN file. It is 1 for the */
/* first day of diary week WEEKI, it is 2 for the second day, etc. */

gen diarydy2 = diaryday + 7*(weeki-1);
egen minday = min(diarydy2), by(hhid);
egen maxday = max(diarydy2), by(hhid);
gen firstday = minday==diarydy2;
gen numdays = maxday - minday + 1;
tabulate numdays if firstday==1;


/* Create some demographic variables */
gen white = ref_race==1;
gen black = ref_race==2;
gen othrace = ref_race>3&ref_race!=.;

/* Education coding is based on 1993 and earlier coding */
gen ed_lths = educ_ref==1|educ_ref==2|educ_ref==7;
gen ed_hs = educ_ref==3;
gen ed_some = educ_ref==4;
gen ed_coll = educ_ref==5|educ_ref==6;
gen ed_anyco = educ_ref==4|educ_ref==5|educ_ref==6;

gen male = sex_ref==1;

gen married = marital1==1;
gen widowed = marital1==2;
gen divorced = marital1==3;
gen separate = marital1==4;
gen nevmarry = marital1==5;


/* CREATE EXPENDITURE VARIABLES */
/* Expenditure variables already created are: */
/* TOTALEXP: total expenditures for the day */
/* FOODHOM2: Food at home including alcohol */
/* FOODAWA2: Food away from home including alcohol */
/* TOTAWAY: Away from home spending which includes food and alcohol away */
/*          plus entertainment expenditures */
/*          Entertainment expenditures are : */
/*          Fees for participant sports, for movies/concerts, */
/*          for sporting events, for recreational lessons, */
/*          for renting videos, for coin-op video games */
/* The entertainment UCCs are 620121,620211,620221,620310,620912,620913 */
/* FRESH: Fresh food expenditures */

/* Create two more expenditure categories */
/* STNONDUR is related to Lusardi's strict non-durable category */
/* But I've tried to eliminate things that might have a regular payment freq */
/* So, it is all food, all alcohol, all tobacco, all personal care, */
/* all public transportation, and all gas/motor oil . */
/* What I've left out from Lusardi is utilities, hhold operations, & miscel */
gen stnondur = foodtot2 + smoksupp + persprod + persserv + pubtran + gas;

/* PURE is a pure consumption category */
/* It is total away category (food & alcohol away plus the */
/* entertainment category discussed above) plus fresh foods */ 
gen pure = fresh + totaway;


/* CREATE INDICATORS FOR HAVING ANY DAILY EXPENDITURES IN A CATEGORY */
gen havtotal = totalexp>0;
gen havsndur = stnondur>0;
gen havfhom2 = foodhom2>0;
gen havfawa2 = foodawa2>0;
gen havtaway = totaway>0;
gen havfresh = fresh>0;
gen havpure  = pure>0;



/* CREATE ADDITIONAL REGRESSORS */

/* The day of week indicators TUE, WED, THU,..., SUN are created from */
/* the day of week variable. That variable is the second character of */
/* the character variable QREDATE on the EXPN file. It is 1 for the */
/* Sunday, 2 for Monday, etc. */

/* The seven survey day indicators - SURVDAY1-SURVDAY7 */
/* are created from the DIARYDAY variable discussed above */

/* Generate survey day interacted with second diary week */
gen sweek2 = weeki==2;
gen swk2day1 = survday1*sweek2;
gen swk2day2 = survday2*sweek2;
gen swk2day3 = survday3*sweek2;
gen swk2day4 = survday4*sweek2;
gen swk2day5 = survday5*sweek2;
gen swk2day6 = survday6*sweek2;
gen swk2day7 = survday7*sweek2;



/* TABLE 1 - MEANS BY WEEK IN 28 DAY WINDOW THAT INTERVIEW BEGAN */

/* Split households by where in the 28 day window the first day of the */
/* interview lies */
/* The variable d_week1-d_week4 are indicators for the day being in */
/* 8 to 14 days before check receipt (d_week1==1) */
/* 1 to 7 days before check receipt (d_week2==1) */
/* 0 to 6 days after check receipt (d_week3==1) */
/* 7 to 13 days after check receipt (d_week4==1) */

/* Examine the distribution of households across the four groups */
/* 8 to 14 days before check receipt (d_week1==1) */
ci        age_ref male ed_hs ed_anyco fam_size fincbefx fss_rrx
          if d_week1==1&firstday==1;
/* 1 to 7 days before check receipt (d_week2==1) */
ci        age_ref male ed_hs ed_anyco fam_size fincbefx fss_rrx
          if d_week2==1&firstday==1;
/* 0 to 6 days after check receipt (d_week3==1) */
ci        age_ref male ed_hs ed_anyco fam_size fincbefx fss_rrx
          if d_week3==1&firstday==1;
/* 7 to 13 days after check receipt (d_week4==1) */
ci        age_ref male ed_hs ed_anyco fam_size fincbefx fss_rrx
          if d_week4==1&firstday==1;


/* TABLE 2 - OLS HOUSEHOLD FIXED EFFECT REGRESSIONS */
/*           USING WEEKLY INDICATORS */
/*           USE TO SET STARTING VALUES FOR THE PANEL TOBIT ESTIMATOR */
/*           ALL HOUSEHOLDS */
sum totalexp stnondur foodhom2 foodawa2 totaway fresh pure;
sum hav*;

/* Run regressions to set starting values for TABLE 2 */
for var totalexp stnondur foodhom2 foodawa2 totaway fresh pure:
    areg X survday2-survday7 sweek2 swk2day2-swk2day7 tue wed thu fri sat sun
         d_week1 d_week3 d_week4, absorb(hhid) cluster(hhid);



/* TABLE 3 - OLS HOUSEHOLD FIXED EFFECT REGRESSIONS */
/*           USING WEEKLY INDICATORS */
/*           USE TO SET STARTING VALUES FOR THE PANEL TOBIT ESTIMATOR */
/*           HOUSEHOLDS W/70% OR MORE OF INCOME FROM S.S. */
sum totalexp stnondur foodhom2 foodawa2 totaway fresh pure if ssratio>=.70;
sum hav* if ssratio>=.70;

for var totalexp stnondur foodhom2 foodawa2 totaway fresh pure:
    areg X survday2-survday7 sweek2 swk2day2-swk2day7 tue wed thu fri sat sun
         d_week1 d_week3 d_week4 if ssratio>=.70, absorb(hhid) cluster(hhid);



/* TABLE 4 - IMPACT OF CHECK RECEIPT ON PROBABILITY OF SPENDING */
/*           BY WEEK IN 28 DAY WINDOW */

/* Summarize making daily expenditures by category */
/* ALL HOUSEHOLDS */
sum hav*;
/* HOUSEHOLDS W/70% OR MORE OF INCOME FROM S.S. */
sum hav* if ssratio>=.70;

/* ALL HOUSEHOLDS */
for var havtotal havsndur havfhom2 havfawa2 havtaway havfresh havpure:
    areg X survday2-survday7 sweek2 swk2day2-swk2day7 tue wed thu fri sat sun
         d_week1 d_week3 d_week4, absorb(hhid) cluster(hhid);

/* HOUSEHOLDS W/70% OR MORE OF INCOME FROM S.S. */
for var havtotal havsndur havfhom2 havfawa2 havtaway havfresh havpure:
    areg X survday2-survday7 sweek2 swk2day2-swk2day7 tue wed thu fri sat sun
         d_week1 d_week3 d_week4 if ssratio>=.70, absorb(hhid) cluster(hhid);



/* FIGURE 1 - AVERAGE DAILY SPENDING IN 28 DAY WINDOW */
sum totalexp stnondur foodhom2 foodawa2;
table anndif3a, c(n totalexp mean totalexp n stnondur mean stnondur);
table anndif3a, c(n foodhom2 mean foodhom2 n foodawa2 mean foodawa2);


/* FIGURE 2 - PROBABILITY OF MAKING DAILY EXPENDITURE IN 28 DAY WINDOW */
sum havtotal havsndur havfhom2 havfawa2;
table anndif3a, c(n havtotal mean havtotal n havsndur mean havsndur);
table anndif3a, c(n havfhom2 mean havfhom2 n havfawa2 mean havfawa2);


/* FIGURE 3 - OLS HOUSEHOLD FIXED EFFECT REGRESSIONS */
/*            USING DAILY INDICATORS */
/*            USE TO SET STARTING VALUES FOR THE PANEL TOBIT ESTIMATOR */
/*            ALL HOUSEHOLDS */
for var totalexp stnondur foodhom2 foodawa2 totaway fresh pure:
    areg X survday2-survday7 sweek2 swk2day2-swk2day7 tue wed thu fri sat sun
         d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7
         d_min6 d_min5 d_min4 d_min3 d_min2 d_0 d_plus1 d_plus2
         d_plus3 d_plus4 d_plus5 d_plus6 d_plus7 d_plus8 d_plus9
         d_plus10 d_plus11 d_plus12 d_plus13,
         absorb(hhid) cluster(hhid);


/* FIGURE 4 - OLS HOUSEHOLD FIXED EFFECT REGRESSIONS */
/*            USING DAILY INDICATORS */
/*            USE TO SET STARTING VALUES FOR THE PANEL TOBIT ESTIMATOR */
/*            HOUSEHOLDS W/70% OR MORE OF INCOME FROM S.S. */
for var totalexp stnondur foodhom2 foodawa2 totaway fresh pure:
    areg X survday2-survday7 sweek2 swk2day2-swk2day7 tue wed thu fri sat sun
         d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7
         d_min6 d_min5 d_min4 d_min3 d_min2 d_0 d_plus1 d_plus2
         d_plus3 d_plus4 d_plus5 d_plus6 d_plus7 d_plus8 d_plus9
         d_plus10 d_plus11 d_plus12 d_plus13 if ssratio>=.70,
         absorb(hhid) cluster(hhid);



/* FIGURE 5  - IMPACT OF CHECK RECEIPT ON PROBABILITY OF SPENDING */
/*             BY DAY IN 28 DAY WINDOW */
/* ALL HOUSEHOLDS */
for var havtotal havsndur havfhom2 havfawa2 havtaway havfresh havpure:
    areg X survday2-survday7 sweek2 swk2day2-swk2day7 tue wed thu fri sat sun
         d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7
         d_min6 d_min5 d_min4 d_min3 d_min2 d_0 d_plus1 d_plus2
         d_plus3 d_plus4 d_plus5 d_plus6 d_plus7 d_plus8 d_plus9
         d_plus10 d_plus11 d_plus12 d_plus13,
         absorb(hhid) cluster(hhid);


/* FIGURE 6  - IMPACT OF CHECK RECEIPT ON PROBABILITY OF SPENDING */
/*             BY DAY IN 28 DAY WINDOW */
/* HOUSEHOLDS W/70% OR MORE OF INCOME FROM S.S. */
for var havtotal havsndur havfhom2 havfawa2 havtaway havfresh havpure:
    areg X survday2-survday7 sweek2 swk2day2-swk2day7 tue wed thu fri sat sun
         d_min14 d_min13 d_min12 d_min11 d_min10 d_min9 d_min8 d_min7
         d_min6 d_min5 d_min4 d_min3 d_min2 d_0 d_plus1 d_plus2
         d_plus3 d_plus4 d_plus5 d_plus6 d_plus7 d_plus8 d_plus9
         d_plus10 d_plus11 d_plus12 d_plus13 if ssratio>=.70,
         absorb(hhid) cluster(hhid);
